@@ -29,7 +29,7 @@ def get_line_reader(config):
     line_reader = None
     reader_section = config.get(config_param.DATA_SECTION, config_param.LINE_READER) 
     line_reader_module = config.get(reader_section, config_param.LINE_READER_MODULE)
-    print "importing %s" %line_reader_module
+    print "import %s" % line_reader_module
     exec "import %s" % line_reader_module
     exec "line_reader = %s.LineReader(config)" % line_reader_module 
     return line_reader
